#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://xchat.org/
# last revised       : 1.6.2010

set -x -e -u

softname='xchat'
softversion='2.8.8'
packageversion='66.1'

arch='i486'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://xchat.org/files/source/2.8/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
xchat: xchat (GTK+-based IRC client)
xchat:
xchat: X-Chat is a GTK+-based IRC (Internet Relay Chat) client.
xchat:
xchat:
xchat:
xchat:
xchat:
xchat:
xchat:
xchat:
EOF

# check if package is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg

# build
cd $src

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
	--prefix=/usr \
	--mandir=/usr/man \
	--localstatedir=/var/lib \
      --enable-ipv6 \
      --build=$arch-slackware-linux || exit

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
       AUTHORS COPYING ChangeLog INSTALL HACKING README \
       $dest/usr/doc/$softname-$softversion

# Strip
( cd $dest
  find . | xargs file | grep -e "executable" -e "shared object" | grep ELF | cut -s -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/xchat/source/build-xchat.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
